==> pkgtools-ng-0.2-i486-72.1.txz: usr/src/zenpakt-0.2/build-zenpakt.sh <==
#!/bin/bash

#       build-zenpakt.sh
#       This file is part of zenpakt
#
#       Copyright 2010 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       Zenapkt is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

#Configuration variables
#=======================

#the zenpakt version
version=0.2

#the zenwalk version
zenwalk_version=72

#the build number
build_number=1

#the package name
package_name=${1:-zenpakt}

#The direcory where the package will be generated
build_dir=./.package

error() {
  echo "error: $1" >&2
  rm -f doc/slack-desc
  exit 1
}

#Generate slack-desc
while read -r ; do
  printf '%s: %s\n' "$package_name" "$REPLY"
done < doc/slack-desc.in > doc/slack-desc

#cleanup first
make distclean

#configure the package
CFLAGS="-O2 -march=i486 -mtune=i686" ./configure --prefix=/usr --sbindir=/sbin --docdir=/usr/doc --mandir=/usr/man

#./configure --prefix=/usr --sbindir=/sbin --docdir=/usr/doc/zenpakt-"$version" --mandir=/usr/man

#make
make || error "error while running make"

#create the build directory
rm -rf "$build_dir" || error "creating $build_dir failed"
mkdir "$build_dir" || error "creating $build_dir failed"

make zeninstall DESTDIR="$build_dir" || error "running make zeninstall"

rm -f doc/slack-desc

cd "$build_dir" || error "couldn't change directory to $build_dir"

makepkg --linkadd y --chown n "../$package_name-$version-i486-$zenwalk_version.$build_number.txz"

cd .. && rm -rf "$build_dir"

#create md5
md5sum -- \
  "$package_name-$version-i486-$zenwalk_version.$build_number.txz" > \
  "$package_name-$version-i486-$zenwalk_version.$build_number.md5"

==> pkgtools-ng-0.2.0.3-i486-66.1.txz: usr/src/zenpakt-0.2.0.3/build-zenpakt.sh <==
#!/bin/bash

#       build-zenpakt.sh
#       This file is part of zenpakt
#
#       Copyright 2010 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       Zenapkt is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

#Configuration variables
#=======================

#the zenpakt version
version=0.2.0.3

#the zenwalk version
zenwalk_version=66

#the build number
build_number=1

#the package name
package_name=${1:-zenpakt}

#The direcory where the package will be generated
build_dir=./.package

error() {
  echo "error: $1" >&2
  rm -f doc/slack-desc
  exit 1
}

#Generate slack-desc
while read -r ; do
  printf '%s: %s\n' "$package_name" "$REPLY"
done < doc/slack-desc.in > doc/slack-desc

#configure the package
CFLAGS="-O2 -march=i486 -mtune=i686" ./configure --prefix=/usr --sbindir=/sbin --docdir=/usr/doc/zenpakt-"$version" --mandir=/usr/man

#./configure --prefix=/usr --sbindir=/sbin --docdir=/usr/doc/zenpakt-"$version" --mandir=/usr/man

#make
make || error "error while running make"

#create the build directory
rm -rf "$build_dir" || error "creating $build_dir failed"
mkdir "$build_dir" || error "creating $build_dir failed"

make zeninstall DESTDIR="$build_dir" || error "running make zeninstall"

rm -f doc/slack-desc

cd "$build_dir" || error "couldn't change directory to $build_dir"

makepkg --linkadd y --chown n "../$package_name-$version-i486-$zenwalk_version.$build_number.txz"

cd .. && rm -rf "$build_dir"
